/// <reference types="node" />
import { MessageConnection } from 'vscode-jsonrpc';
import { EventEmitter } from 'events';
/**
 * Helper class for sending requests and notifications
 */
export declare class Common {
    /**
     * Template method for sending requests and receiving the response
     * @param connection the message connection to SSP server
     * @param messageType type of the message being sent
     * @param payload parameters of the message being sent
     * @param timeout timeout in milliseconds
     * @param timeoutMessage error message in case of timeout
     */
    static sendSimpleRequest(connection: MessageConnection, messageType: any, payload: any, timeout: number, timeoutMessage: string): Promise<any>;
    /**
     * Template method for sending notifications and synchronously waiting for a response by subscribing to an event
     * @param connection the message connection to SSP server
     * @param messageType type of the message being sent
     * @param payload parameters of the message being sent
     * @param emitter event emitter used to subscribe for the response event
     * @param eventId id/name of the response event to wait for
     * @param timeout timeout in milliseconds
     * @param timeoutMessage error message in case of timeout
     */
    static sendNotificationSync(connection: MessageConnection, messageType: any, payload: any, emitter: EventEmitter, eventId: string, timeout: number, timeoutMessage: string): Promise<any>;
    /**
     * Template method for sending simple notifications to the server
     * @param connection message connection to the server
     * @param messageType type of the notification being sent
     * @param payload payload (parameters) of the message being sent
     */
    static sendSimpleNotification(connection: MessageConnection, messageType: any, payload: any): void;
}
/**
 * Error messages
 */
export declare namespace ErrorMessages {
    const FINDBEANS_TIMEOUT = "Failed to retrieve server beans in time";
    const ADDPATH_TIMEOUT = "Failed to add discovery path in time";
    const REMOVEPATH_TIMEOUT = "Failed to remove discovery path in time";
    const GETPATHS_TIMEOUT = "Failed to retrieve discovery paths in time";
    const GETSERVERS_TIMEOUT = "Failed to retrieve servers in time";
    const GETREQUIREDATTRS_TIMEOUT = "Failed to retrieve required server attributes in time";
    const GETOPTIONALATTRS_TIMEOUT = "Failed to retrieve optional server attributes in time";
    const DELETESERVERSYNC_TIMEOUT = "Failed to delete server in time";
    const GETLAUNCHMODES_TIMEOUT = "Failed to get launch modes in time";
    const GETREQUIREDLAUNCHATTRS_TIMEOUT = "Failed to get required launch attributes in time";
    const GETOPTIONALLAUNCHATTRS_TIMEOUT = "Failed to get optional launch attributes in time";
    const GETLAUNCHCOMMAND_TIMEOUT = "Failed to get launch command in time";
    const SERVERSTARTINGBYCLIENT_TIMEOUT = "Failed to notify of server starting in time";
    const SERVERSTARTEDBYCLIENT_TIMEOUT = "Failed to notify of server started in time";
    const STARTSERVER_TIMEOUT = "Failed to start server in time";
    const STOPSERVER_TIMEOUT = "Failed to stop server in time";
    const CREATESERVER_TIMEOUT = "Failed to create server in time";
}
